\r mysql
INSERT INTO 
   user ( host, user, password )
VALUES (
      'localhost',
      'hordemgr',
      password( 'hordemgr' )
);

